==> kadaster-gds2-2.2-sources.jar: nl/kadaster/schemas/generiek_extern/procesresultaat/v20110922/ObjectFactory.java <==

package nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _ProcesVerwerking_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "ProcesVerwerking");
    private final static QName _Melding_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "Melding");
    private final static QName _ProcesVerwerkingCode_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "ProcesVerwerkingCode");
    private final static QName _SeverityCode_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "SeverityCode");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ProcesVerwerking }
     * 
     */
    public ProcesVerwerking createProcesVerwerking() {
        return new ProcesVerwerking();
    }

    /**
     * Create an instance of {@link Melding }
     * 
     */
    public Melding createMelding() {
        return new Melding();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ProcesVerwerking }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ProcesVerwerking }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "ProcesVerwerking")
    public JAXBElement<ProcesVerwerking> createProcesVerwerking(ProcesVerwerking value) {
        return new JAXBElement<ProcesVerwerking>(_ProcesVerwerking_QNAME, ProcesVerwerking.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Melding }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Melding }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "Melding")
    public JAXBElement<Melding> createMelding(Melding value) {
        return new JAXBElement<Melding>(_Melding_QNAME, Melding.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "ProcesVerwerkingCode", defaultValue = "1")
    public JAXBElement<String> createProcesVerwerkingCode(String value) {
        return new JAXBElement<String>(_ProcesVerwerkingCode_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "SeverityCode", defaultValue = "INFO")
    public JAXBElement<String> createSeverityCode(String value) {
        return new JAXBElement<String>(_SeverityCode_QNAME, String.class, null, value);
    }

}

==> kadaster-gds2-4.0-sources.jar: nl/kadaster/schemas/generiek_extern/procesresultaat/v20110922/ObjectFactory.java <==

package nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private static final QName _ProcesVerwerking_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "ProcesVerwerking");
    private static final QName _Melding_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "Melding");
    private static final QName _ProcesVerwerkingCode_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "ProcesVerwerkingCode");
    private static final QName _SeverityCode_QNAME = new QName("http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", "SeverityCode");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.generiek_extern.procesresultaat.v20110922
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link ProcesVerwerking }
     * 
     */
    public ProcesVerwerking createProcesVerwerking() {
        return new ProcesVerwerking();
    }

    /**
     * Create an instance of {@link Melding }
     * 
     */
    public Melding createMelding() {
        return new Melding();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ProcesVerwerking }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ProcesVerwerking }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "ProcesVerwerking")
    public JAXBElement<ProcesVerwerking> createProcesVerwerking(ProcesVerwerking value) {
        return new JAXBElement<ProcesVerwerking>(_ProcesVerwerking_QNAME, ProcesVerwerking.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Melding }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link Melding }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "Melding")
    public JAXBElement<Melding> createMelding(Melding value) {
        return new JAXBElement<Melding>(_Melding_QNAME, Melding.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "ProcesVerwerkingCode", defaultValue = "1")
    public JAXBElement<String> createProcesVerwerkingCode(String value) {
        return new JAXBElement<String>(_ProcesVerwerkingCode_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/generiek-extern/procesresultaat/v20110922", name = "SeverityCode", defaultValue = "INFO")
    public JAXBElement<String> createSeverityCode(String value) {
        return new JAXBElement<String>(_SeverityCode_QNAME, String.class, null, value);
    }

}
